How to contribute
=================

Reporting problems
------------------

If you find a bug in Patterns please report to it us. Doing so is very simple:

* Make sure you have a [GitHub account](https://github.com/signup/free).
* [Submit a ticket for your
  issue](https://github.com/Patternslib/Patterns/issues/new), assuming one does
  not already exist. Make sure to clearly describe the issue, including steps
  to reproduce when it is a bug.
* If possible include a small test case demonstrating the problem. This can either
  be provided in the ticket itself, or through a pointer to a
  [JSFiddle](http://jsfiddle.net/).

Contributing code
-----------------

All code contributions are extremely welcome. In order to contribute please make
sure you have do the following:

* Read our [code style guide](docs/styleguide.md).
* Make sure you have a [GitHub account](https://github.com/signup/free).
* Create a topic branch from where you want to base your work.
* Make sure *all* tests are passing before you commit your changes. Use the ``make
  check`` command to do this.
* Submit a pull request.

